Module: Finder::Find
- Extended by:
- Find
- Defined in:
- lib/finder/find.rb,
lib/finder/gem.rb,
lib/finder/base.rb,
lib/finder/roll.rb,
lib/finder/site.rb
Overview
Find module is the main interface for Finder library.
Defined Under Namespace
Modules: Base, Gem, Roll, Site
Constant Summary collapse
- EXTENSIONS =
TODO: expand on extensions
%w{.rb .rbx .so}
Instance Method Summary collapse
-
#data_path(match, options = {}) ⇒ Object
Searching through all systems for matching data paths.
-
#feature(match, options = {}) ⇒ Object
Searching through all systems for matching requirable feature files.
-
#load_path(match, options = {}) ⇒ Object
Searching through all systems for matching load paths.
-
#path(match, options = {}) ⇒ Object
(also: #[])
Find matching paths, searching through Rolled libraries, Gem-installed libraries and site locations in
$LOAD_PATHandRbConfig::CONFIG['datadir']. -
#systems ⇒ Object
List of supported library management systems.
Instance Method Details
#data_path(match, options = {}) ⇒ Object
Searching through all systems for matching data paths.
48 49 50 51 52 53 54 |
# File 'lib/finder/find.rb', line 48 def data_path(match, ={}) found = [] systems.each do |system| found.concat system.data_path(match, ) end found.uniq end |
#feature(match, options = {}) ⇒ Object
Searching through all systems for matching requirable feature files.
96 97 98 99 100 101 102 |
# File 'lib/finder/find.rb', line 96 def feature(match, ={}) found = [] systems.each do |system| found.concat system.feature(match, ) end found.uniq end |
#load_path(match, options = {}) ⇒ Object
Searching through all systems for matching load paths.
64 65 66 67 68 69 70 |
# File 'lib/finder/find.rb', line 64 def load_path(match, ={}) found = [] systems.each do |system| found.concat system.load_path(match, ) end found.uniq end |
#path(match, options = {}) ⇒ Object Also known as: []
Find matching paths, searching through Rolled libraries, Gem-installed libraries
and site locations in $LOAD_PATH and RbConfig::CONFIG['datadir'].
26 27 28 29 30 31 32 |
# File 'lib/finder/find.rb', line 26 def path(match, ={}) found = [] systems.each do |system| found.concat system.path(match, ) end found.uniq end |
#systems ⇒ Object
List of supported library management systems.
107 108 109 110 111 112 113 114 115 |
# File 'lib/finder/find.rb', line 107 def systems @systems ||= ( systems = [] systems << Roll if defined?(::Library) systems << Gem if defined?(::Gem) systems << Site systems ) end |